Crate icu_displaynames_data
source ·Expand description
Data for the icu_displaynames crate
Macros
- Implement
DataProvider<LanguageDisplayNamesV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - Implement
DataProvider<LocaleDisplayNamesV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - Implement
DataProvider<RegionDisplayNamesV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - Implement
DataProvider<ScriptDisplayNamesV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - Implement
DataProvider<VariantDisplayNamesV1Marker>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - Marks a type as a data provider. You can then use macros like
impl_core_helloworld_v1to add implementations.